@@ -3,6 +3,7 @@
 import functools
 import json
 import operator
+import os
 import pathlib
 import stat
 import subprocess
@@ -52,7 +53,7 @@ class RealFileAccessor:
       return
     targetDir = path.dirname(path.realpath(filename))
     pathlib.Path(targetDir).mkdir(parents=True, exist_ok=True)
-    with open(filename, 'w') as f:
+    with open(os.open(filename, os.O_CREAT | os.O_WRONLY | os.O_TRUNC, 0o600), 'w') as f:
       f.write(content)
 
   def abspath(self, filepath):
@@ -444,6 +445,7 @@ class Kubedev:
       add_unknown_variable_overrides: bool = False,
       get_output: bool = False):
     variables = KubedevConfig.get_global_variables(kubedev)
+    listResourcesCmd = None
     if docker_network is not None:
       kubeContext = env_accessor.getenv('KUBEDEV_KUBECONTEXT')
       envs = KubedevConfig.get_helm_set_env_args(
@@ -470,7 +472,7 @@ class Kubedev:
           f'{normalized_kubeconfig}:/tmp/kube_config',
           '--volume',
           f'{KubedevConfig.wsl_normalize(helm_chart, file_accessor, shell_executor)}:/app/helm-chart/',
-          'alpine/helm:2.17.0',
+          'alpine/helm:3.8.0',
           'upgrade',
           release_name,
           '/app/helm-chart/',
@@ -498,10 +500,21 @@ class Kubedev:
           f'--set KUBEDEV_TAG="{tag}"' +
           envs['cmdline']
       ]
+      listResourcesCmd = [
+        '/bin/sh', '-c', f'helm get manifest --kubeconfig {kubeconfig} {release_name} | kubectl get -f -'
+      ]
     if not get_output:
-      return shell_executor.execute(command, {**variables, **envs['envs']})
+      result = shell_executor.execute(command, {**variables, **envs['envs']})
     else:
-      return shell_executor.get_output(command, {**variables, **envs['envs']})
+      result = shell_executor.get_output(command, {**variables, **envs['envs']})
+
+    if result != 0:
+      return result
+    elif listResourcesCmd is not None:
+      shell_executor.execute(listResourcesCmd)
+      return result
+    else:
+      return result
 
   def template(self, configFileName, shell_executor=RealShellExecutor(), env_accessor=RealEnvAccessor(), file_accessor=RealFileAccessor()):
     return self.template_from_config(
@@ -1105,9 +1118,6 @@ class Kubedev:
             ]
             if createCluster:
               # Step #3.2: For CronJobs: Init helm, set docker registry secret
-              if not KubernetesTools.apply(network, wslClusterConfig, KubernetesTools.get_tiller_rbac_setup(), shell_executor):
-                return False
-
               if KubernetesTools.kubectl(
                 network,
                 wslClusterConfig,
@@ -1122,34 +1132,6 @@ class Kubedev:
                 shell_executor) != 0:
                 return False
 
-              cmdHelmInit = [
-                'docker',
-                'run',
-                '-i',
-                '--rm',
-                '--network',
-                network,
-                '--user',
-                '0',
-                '--volume',
-                f'{wslClusterConfig}:/tmp/kube_config',
-                'alpine/helm:2.17.0',
-                '--kubeconfig',
-                '/tmp/kube_config',
-                'init',
-                '--stable-repo-url',
-                'https://charts.helm.sh/stable',
-                '--service-account',
-                'tiller'
-              ]
-              if shell_executor.execute(cmdHelmInit, check=False) != 0:
-                  return False
-              timeout = 600
-              print(f'{colorama.Fore.YELLOW}Waiting {timeout} seconds for Tiller deployment to become ready...')
-              if not KubernetesTools.wait_for_deployment(network, wslClusterConfig, "kube-system", "tiller-deploy", timeout, shell_executor, sleeper):
-                print(f'{colorama.Fore.RED}Tiller deployment did not become ready within timeout of {timeout} seconds :-(')
-                return False
-
             # Step #3.3: Deploy the clusterInitChart (optional) and this helm-chart
             if 'clusterInitChart' in systemTestDefinition:
               clusterInitChartPath = systemTestDefinition['clusterInitChart']
